Installation
============

CamoTSS is available through `PyPI <https://pypi.org/project/CamoTSS/>`_.
To install, type the following command line and add ``-U`` for updates:

.. code-block:: bash

   pip install -U CamoTSS

Alternatively, you can install from this GitHub repository for latest (often
development) version by the following command line:

.. code-block:: bash

   pip install -U git+https://github.com/StatBiomed/CamoTSS

In either case, add --user if you don’t have the write permission for your Python environment.

